.. image:: https://github.com/matthiaskoenig/protein-distribution/raw/main/docs/images/favicon/protein-distribution-100x100-300dpi.png
   :align: left
   :alt: protein-distribution logo

protein-distribution: protein variability of CYP, UGT, ABC and SLC in human liver
=================================================================================

.. image:: https://github.com/matthiaskoenig/protein_distribution/workflows/CI-CD/badge.svg
   :target: https://github.com/matthiaskoenig/protein_distribution/workflows/CI-CD
   :alt: GitHub Actions CI/CD Status

.. image:: https://img.shields.io/pypi/v/protein_distribution.svg
   :target: https://pypi.org/project/protein_distribution/
   :alt: Current PyPI Version

.. image:: https://img.shields.io/pypi/pyversions/protein_distribution.svg
   :target: https://pypi.org/project/protein_distribution/
   :alt: Supported Python Versions

.. image:: https://img.shields.io/pypi/l/protein_distribution.svg
   :target: http://opensource.org/licenses/LGPL-3.0
   :alt: GNU Lesser General Public License 3

.. image:: https://codecov.io/gh/matthiaskoenig/protein_distribution/branch/develop/graph/badge.svg
   :target: https://codecov.io/gh/matthiaskoenig/protein_distribution
   :alt: Codecov

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
   :target: https://github.com/ambv/black
   :alt: Black

.. image:: http://www.mypy-lang.org/static/mypy_badge.svg
   :target: http://mypy-lang.org/
   :alt: mypy

The objective of this project is to provide a systematic overview of protein variability of CYP450, UGT, ABC and SLC isoforms in the human liver. Relationships within protein isoforms (e.g., subgroups such as sex or ethnicity) and between CYP450 isoforms (e.g., correlations) will be studied. The project will provide an important resource to elucidate factors affecting individual drug metabolism and for computational modeling of drug detoxification by the liver.

An interactive web application is available from 
`https://github.com/matthiaskoenig/protein-distribution-app <https://github.com/matthiaskoenig/protein-distribution-app>`__.

License
=======

* Source Code: `LGPLv3 <http://opensource.org/licenses/LGPL-3.0>`__
* Documentation: `CC BY-SA 4.0 <http://creativecommons.org/licenses/by-sa/4.0/>`__

The protein-distribution source is released under both the GPL and LGPL licenses version 2 or
later. You may choose which license you choose to use the software under.

This program is free software: you can redistribute it and/or modify it under
the terms of the GNU General Public License or the GNU Lesser General Public
License as published by the Free Software Foundation, either version 2 of the
License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
PARTICULAR PURPOSE. See the GNU General Public License for more details.

Funding
=======
Matthias König is supported by the Federal Ministry of Education and Research (BMBF, Germany)
within the research network Systems Medicine of the Liver (**LiSyM**, grant number 031L0054)
and by the German Research Foundation (DFG) within the Research Unit Programme FOR 5151
"`QuaLiPerF <https://qualiperf.de>`__ (Quantifying Liver Perfusion-Function Relationship in Complex Resection -
A Systems Medicine Approach)" by grant number 436883643 and by grant number
465194077 (Priority Programme SPP 2311, Subproject SimLivA).

© 2022-2023 Afruja Hossain, Sophie Silberhorn & Matthias König
